@@ -13,6 +13,7 @@ def cli_is_multiline(mycli):
             return False
         else:
             return not _multiline_exception(doc.text)
+
     return cond
 
 
@@ -23,33 +24,32 @@ def _multiline_exception(text):
     # Multi-statement favorite query is a special case. Because there will
     # be a semicolon separating statements, we can't consider semicolon an
     # EOL. Let's consider an empty line an EOL instead.
-    if text.startswith('\\fs'):
-        return orig.endswith('\n')
+    if text.startswith("\\fs"):
+        return orig.endswith("\n")
 
     return (
         # Special Command
-        text.startswith('\\') or
-
+        text.startswith("\\")
+        or
         # Delimiter declaration
-        text.lower().startswith('delimiter') or
-
+        text.lower().startswith("delimiter")
+        or
         # Ended with the current delimiter (usually a semi-column)
-        text.endswith(special.get_current_delimiter()) or
-
-        text.endswith('\\g') or
-        text.endswith('\\G') or
-        text.endswith(r'\e') or
-        text.endswith(r'\clip') or
-
+        text.endswith(special.get_current_delimiter())
+        or text.endswith("\\g")
+        or text.endswith("\\G")
+        or text.endswith(r"\e")
+        or text.endswith(r"\clip")
+        or
         # Exit doesn't need semi-column`
-        (text == 'exit') or
-
+        (text == "exit")
+        or
         # Quit doesn't need semi-column
-        (text == 'quit') or
-
+        (text == "quit")
+        or
         # To all teh vim fans out there
-        (text == ':q') or
-
+        (text == ":q")
+        or
         # just a plain enter without any text
-        (text == '')
+        (text == "")
     )
