@@ -12,8 +12,7 @@ def suggest_type(full_text, text_before_cursor):
     A scope for a column category will be a list of tables.
     """
 
-    word_before_cursor = last_word(text_before_cursor,
-            include='many_punctuations')
+    word_before_cursor = last_word(text_before_cursor, include="many_punctuations")
 
     identifier = None
 
@@ -25,12 +24,10 @@ def suggest_type(full_text, text_before_cursor):
         # partially typed string which renders the smart completion useless because
         # it will always return the list of keywords as completion.
         if word_before_cursor:
-            if word_before_cursor.endswith(
-                    '(') or word_before_cursor.startswith('\\'):
+            if word_before_cursor.endswith("(") or word_before_cursor.startswith("\\"):
                 parsed = sqlparse.parse(text_before_cursor)
             else:
-                parsed = sqlparse.parse(
-                    text_before_cursor[:-len(word_before_cursor)])
+                parsed = sqlparse.parse(text_before_cursor[: -len(word_before_cursor)])
 
                 # word_before_cursor may include a schema qualification, like
                 # "schema_name.partial_name" or "schema_name.", so parse it
@@ -42,7 +39,7 @@ def suggest_type(full_text, text_before_cursor):
         else:
             parsed = sqlparse.parse(text_before_cursor)
     except (TypeError, AttributeError):
-        return [{'type': 'keyword'}]
+        return [{"type": "keyword"}]
 
     if len(parsed) > 1:
         # Multiple statements being edited -- isolate the current one by
@@ -72,13 +69,12 @@ def suggest_type(full_text, text_before_cursor):
         # Be careful here because trivial whitespace is parsed as a statement,
         # but the statement won't have a first token
         tok1 = statement.token_first()
-        if tok1 and (tok1.value == 'source' or tok1.value.startswith('\\')):
+        if tok1 and (tok1.value == "source" or tok1.value.startswith("\\")):
             return suggest_special(text_before_cursor)
 
-    last_token = statement and statement.token_prev(len(statement.tokens))[1] or ''
+    last_token = statement and statement.token_prev(len(statement.tokens))[1] or ""
 
-    return suggest_based_on_last_token(last_token, text_before_cursor,
-                                       full_text, identifier)
+    return suggest_based_on_last_token(last_token, text_before_cursor, full_text, identifier)
 
 
 def suggest_special(text):
@@ -87,27 +83,27 @@ def suggest_special(text):
 
     if cmd == text:
         # Trying to complete the special command itself
-        return [{'type': 'special'}]
+        return [{"type": "special"}]
 
-    if cmd in ('\\u', '\\r'):
-        return [{'type': 'database'}]
+    if cmd in ("\\u", "\\r"):
+        return [{"type": "database"}]
 
-    if cmd in ('\\T'):
-        return [{'type': 'table_format'}]
+    if cmd in ("\\T"):
+        return [{"type": "table_format"}]
 
-    if cmd in ['\\f', '\\fs', '\\fd']:
-        return [{'type': 'favoritequery'}]
+    if cmd in ["\\f", "\\fs", "\\fd"]:
+        return [{"type": "favoritequery"}]
 
-    if cmd in ['\\dt', '\\dt+']:
+    if cmd in ["\\dt", "\\dt+"]:
         return [
-            {'type': 'table', 'schema': []},
-            {'type': 'view', 'schema': []},
-            {'type': 'schema'},
+            {"type": "table", "schema": []},
+            {"type": "view", "schema": []},
+            {"type": "schema"},
         ]
-    elif cmd in ['\\.', 'source']:
-        return[{'type': 'file_name'}]
+    elif cmd in ["\\.", "source"]:
+        return [{"type": "file_name"}]
 
-    return [{'type': 'keyword'}, {'type': 'special'}]
+    return [{"type": "keyword"}, {"type": "special"}]
 
 
 def suggest_based_on_last_token(token, text_before_cursor, full_text, identifier):
@@ -127,18 +123,19 @@ def suggest_based_on_last_token(token, text_before_cursor, full_text, identifier
         # 'where foo > 5 and '. We need to look "inside" token.tokens to handle
         # suggestions in complicated where clauses correctly
         prev_keyword, text_before_cursor = find_prev_keyword(text_before_cursor)
-        return suggest_based_on_last_token(prev_keyword, text_before_cursor,
-                                           full_text, identifier)
+        return suggest_based_on_last_token(prev_keyword, text_before_cursor, full_text, identifier)
     elif token is None:
-        return [{'type': 'keyword'}]
+        return [{"type": "keyword"}]
     else:
         token_v = token.value.lower()
 
-    is_operand = lambda x: x and any([x.endswith(op) for op in ['+', '-', '*', '/']])
+    is_operand = lambda x: x and any([x.endswith(op) for op in ["+", "-", "*", "/"]])  # noqa: E731
 
     if not token:
-        return [{'type': 'keyword'}, {'type': 'special'}]
-    elif token_v.endswith('('):
+        return [{"type": "keyword"}, {"type": "special"}]
+    elif token_v == "*":
+        return [{"type": "keyword"}]
+    elif token_v.endswith("("):
         p = sqlparse.parse(text_before_cursor)[0]
 
         if p.tokens and isinstance(p.tokens[-1], Where):
@@ -153,8 +150,7 @@ def suggest_based_on_last_token(token, text_before_cursor, full_text, identifier
             #        Suggest columns/functions AND keywords. (If we wanted to be
             #        really fancy, we could suggest only array-typed columns)
 
-            column_suggestions = suggest_based_on_last_token('where',
-                                    text_before_cursor, full_text, identifier)
+            column_suggestions = suggest_based_on_last_token("where", text_before_cursor, full_text, identifier)
 
             # Check for a subquery expression (cases 3 & 4)
             where = p.tokens[-1]
@@ -165,130 +161,133 @@ def suggest_based_on_last_token(token, text_before_cursor, full_text, identifier
                 prev_tok = prev_tok.tokens[-1]
 
             prev_tok = prev_tok.value.lower()
-            if prev_tok == 'exists':
-                return [{'type': 'keyword'}]
+            if prev_tok == "exists":
+                return [{"type": "keyword"}]
             else:
                 return column_suggestions
 
         # Get the token before the parens
         idx, prev_tok = p.token_prev(len(p.tokens) - 1)
-        if prev_tok and prev_tok.value and prev_tok.value.lower() == 'using':
+        if prev_tok and prev_tok.value and prev_tok.value.lower() == "using":
             # tbl1 INNER JOIN tbl2 USING (col1, col2)
             tables = extract_tables(full_text)
 
             # suggest columns that are present in more than one table
-            return [{'type': 'column', 'tables': tables, 'drop_unique': True}]
-        elif p.token_first().value.lower() == 'select':
+            return [{"type": "column", "tables": tables, "drop_unique": True}]
+        elif p.token_first().value.lower() == "select":
             # If the lparen is preceeded by a space chances are we're about to
             # do a sub-select.
-            if last_word(text_before_cursor,
-                    'all_punctuations').startswith('('):
-                return [{'type': 'keyword'}]
-        elif p.token_first().value.lower() == 'show':
-            return [{'type': 'show'}]
+            if last_word(text_before_cursor, "all_punctuations").startswith("("):
+                return [{"type": "keyword"}]
+        elif p.token_first().value.lower() == "show":
+            return [{"type": "show"}]
 
         # We're probably in a function argument list
-        return [{'type': 'column', 'tables': extract_tables(full_text)}]
-    elif token_v in ('set', 'order by', 'distinct'):
-        return [{'type': 'column', 'tables': extract_tables(full_text)}]
-    elif token_v == 'as':
+        return [{"type": "column", "tables": extract_tables(full_text)}]
+    elif token_v in ("set", "order by", "distinct"):
+        return [{"type": "column", "tables": extract_tables(full_text)}]
+    elif token_v == "as":
         # Don't suggest anything for an alias
         return []
-    elif token_v in ('show'):
-        return [{'type': 'show'}]
-    elif token_v in ('to',):
+    elif token_v in ("show"):
+        return [{"type": "show"}]
+    elif token_v in ("to",):
         p = sqlparse.parse(text_before_cursor)[0]
-        if p.token_first().value.lower() == 'change':
-            return [{'type': 'change'}]
+        if p.token_first().value.lower() == "change":
+            return [{"type": "change"}]
         else:
-            return [{'type': 'user'}]
-    elif token_v in ('user', 'for'):
-        return [{'type': 'user'}]
-    elif token_v in ('select', 'where', 'having'):
+            return [{"type": "user"}]
+    elif token_v in ("user", "for"):
+        return [{"type": "user"}]
+    elif token_v in ("select", "where", "having"):
         # Check for a table alias or schema qualification
         parent = (identifier and identifier.get_parent_name()) or []
 
         tables = extract_tables(full_text)
         if parent:
             tables = [t for t in tables if identifies(parent, *t)]
-            return [{'type': 'column', 'tables': tables},
-                    {'type': 'table', 'schema': parent},
-                    {'type': 'view', 'schema': parent},
-                    {'type': 'function', 'schema': parent}]
+            return [
+                {"type": "column", "tables": tables},
+                {"type": "table", "schema": parent},
+                {"type": "view", "schema": parent},
+                {"type": "function", "schema": parent},
+            ]
         else:
             aliases = [alias or table for (schema, table, alias) in tables]
-            return [{'type': 'column', 'tables': tables},
-                    {'type': 'function', 'schema': []},
-                    {'type': 'alias', 'aliases': aliases},
-                    {'type': 'keyword'}]
-    elif (token_v.endswith('join') and token.is_keyword) or (token_v in
-            ('copy', 'from', 'update', 'into', 'describe', 'truncate',
-                'desc', 'explain')):
+            return [
+                {"type": "column", "tables": tables},
+                {"type": "function", "schema": []},
+                {"type": "alias", "aliases": aliases},
+                {"type": "keyword"},
+            ]
+    elif (token_v.endswith("join") and token.is_keyword) or (
+        token_v in ("copy", "from", "update", "into", "describe", "truncate", "desc", "explain")
+    ):
         schema = (identifier and identifier.get_parent_name()) or []
 
         # Suggest tables from either the currently-selected schema or the
         # public schema if no schema has been specified
-        suggest = [{'type': 'table', 'schema': schema}]
+        suggest = [{"type": "table", "schema": schema}]
 
         if not schema:
             # Suggest schemas
-            suggest.insert(0, {'type': 'schema'})
+            suggest.insert(0, {"type": "schema"})
 
         # Only tables can be TRUNCATED, otherwise suggest views
-        if token_v != 'truncate':
-            suggest.append({'type': 'view', 'schema': schema})
+        if token_v != "truncate":
+            suggest.append({"type": "view", "schema": schema})
 
         return suggest
 
-    elif token_v in ('table', 'view', 'function'):
+    elif token_v in ("table", "view", "function"):
         # E.g. 'DROP FUNCTION <funcname>', 'ALTER TABLE <tablname>'
         rel_type = token_v
         schema = (identifier and identifier.get_parent_name()) or []
         if schema:
-            return [{'type': rel_type, 'schema': schema}]
+            return [{"type": rel_type, "schema": schema}]
         else:
-            return [{'type': 'schema'}, {'type': rel_type, 'schema': []}]
-    elif token_v == 'on':
+            return [{"type": "schema"}, {"type": rel_type, "schema": []}]
+    elif token_v == "on":
         tables = extract_tables(full_text)  # [(schema, table, alias), ...]
         parent = (identifier and identifier.get_parent_name()) or []
         if parent:
             # "ON parent.<suggestion>"
             # parent can be either a schema name or table alias
             tables = [t for t in tables if identifies(parent, *t)]
-            return [{'type': 'column', 'tables': tables},
-                    {'type': 'table', 'schema': parent},
-                    {'type': 'view', 'schema': parent},
-                    {'type': 'function', 'schema': parent}]
+            return [
+                {"type": "column", "tables": tables},
+                {"type": "table", "schema": parent},
+                {"type": "view", "schema": parent},
+                {"type": "function", "schema": parent},
+            ]
         else:
             # ON <suggestion>
             # Use table alias if there is one, otherwise the table name
             aliases = [alias or table for (schema, table, alias) in tables]
-            suggest = [{'type': 'alias', 'aliases': aliases}]
+            suggest = [{"type": "alias", "aliases": aliases}]
 
             # The lists of 'aliases' could be empty if we're trying to complete
             # a GRANT query. eg: GRANT SELECT, INSERT ON <tab>
             # In that case we just suggest all tables.
             if not aliases:
-                suggest.append({'type': 'table', 'schema': parent})
+                suggest.append({"type": "table", "schema": parent})
             return suggest
 
-    elif token_v in ('use', 'database', 'template', 'connect'):
+    elif token_v in ("use", "database", "template", "connect"):
         # "\c <db", "use <db>", "DROP DATABASE <db>",
         # "CREATE DATABASE <newdb> WITH TEMPLATE <db>"
-        return [{'type': 'database'}]
-    elif token_v == 'tableformat':
-        return [{'type': 'table_format'}]
-    elif token_v.endswith(',') or is_operand(token_v) or token_v in ['=', 'and', 'or']:
+        return [{"type": "database"}]
+    elif token_v == "tableformat":
+        return [{"type": "table_format"}]
+    elif token_v.endswith(",") or is_operand(token_v) or token_v in ["=", "and", "or"]:
         prev_keyword, text_before_cursor = find_prev_keyword(text_before_cursor)
         if prev_keyword:
-            return suggest_based_on_last_token(
-                prev_keyword, text_before_cursor, full_text, identifier)
+            return suggest_based_on_last_token(prev_keyword, text_before_cursor, full_text, identifier)
         else:
             return []
     else:
-        return [{'type': 'keyword'}]
+        return [{"type": "keyword"}]
 
 
 def identifies(id, schema, table, alias):
-    return id == alias or id == table or (
-        schema and (id == schema + '.' + table))
+    return id == alias or id == table or (schema and (id == schema + "." + table))
