@@ -4,18 +4,18 @@ from sqlparse.sql import IdentifierList, Identifier, Function
 from sqlparse.tokens import Keyword, DML, Punctuation
 
 cleanup_regex = {
-        # This matches only alphanumerics and underscores.
-        'alphanum_underscore': re.compile(r'(\w+)$'),
-        # This matches everything except spaces, parens, colon, and comma
-        'many_punctuations': re.compile(r'([^():,\s]+)$'),
-        # This matches everything except spaces, parens, colon, comma, and period
-        'most_punctuations': re.compile(r'([^\.():,\s]+)$'),
-        # This matches everything except a space.
-        'all_punctuations': re.compile(r'([^\s]+)$'),
+    # This matches only alphanumerics and underscores.
+    "alphanum_underscore": re.compile(r"(\w+)$"),
+    # This matches everything except spaces, parens, colon, and comma
+    "many_punctuations": re.compile(r"([^():,\s]+)$"),
+    # This matches everything except spaces, parens, colon, comma, and period
+    "most_punctuations": re.compile(r"([^\.():,\s]+)$"),
+    # This matches everything except a space.
+    "all_punctuations": re.compile(r"([^\s]+)$"),
 }
 
 
-def last_word(text, include='alphanum_underscore'):
+def last_word(text, include="alphanum_underscore"):
     r"""
     Find the last word in a sentence.
 
@@ -47,18 +47,18 @@ def last_word(text, include='alphanum_underscore'):
     'def'
     """
 
-    if not text:   # Empty string
-        return ''
+    if not text:  # Empty string
+        return ""
 
     if text[-1].isspace():
-        return ''
+        return ""
     else:
         regex = cleanup_regex[include]
         matches = regex.search(text)
         if matches:
             return matches.group(0)
         else:
-            return ''
+            return ""
 
 
 # This code is borrowed from sqlparse example script.
@@ -67,11 +67,11 @@ def is_subselect(parsed):
     if not parsed.is_group:
         return False
     for item in parsed.tokens:
-        if item.ttype is DML and item.value.upper() in ('SELECT', 'INSERT',
-                'UPDATE', 'CREATE', 'DELETE'):
+        if item.ttype is DML and item.value.upper() in ("SELECT", "INSERT", "UPDATE", "CREATE", "DELETE"):
             return True
     return False
 
+
 def extract_from_part(parsed, stop_at_punctuation=True):
     tbl_prefix_seen = False
     for item in parsed.tokens:
@@ -85,7 +85,7 @@ def extract_from_part(parsed, stop_at_punctuation=True):
             # "ON" is a keyword and will trigger the next elif condition.
             # So instead of stooping the loop when finding an "ON" skip it
             # eg: 'SELECT * FROM abc JOIN def ON abc.id = def.abc_id JOIN ghi'
-            elif item.ttype is Keyword and item.value.upper() == 'ON':
+            elif item.ttype is Keyword and item.value.upper() == "ON":
                 tbl_prefix_seen = False
                 continue
             # An incomplete nested select won't be recognized correctly as a
@@ -96,24 +96,28 @@ def extract_from_part(parsed, stop_at_punctuation=True):
             # Also 'SELECT * FROM abc JOIN def' will trigger this elif
             # condition. So we need to ignore the keyword JOIN and its variants
             # INNER JOIN, FULL OUTER JOIN, etc.
-            elif item.ttype is Keyword and (
-                    not item.value.upper() == 'FROM') and (
-                    not item.value.upper().endswith('JOIN')):
+            elif item.ttype is Keyword and (not item.value.upper() == "FROM") and (not item.value.upper().endswith("JOIN")):
                 return
             else:
                 yield item
-        elif ((item.ttype is Keyword or item.ttype is Keyword.DML) and
-                item.value.upper() in ('COPY', 'FROM', 'INTO', 'UPDATE', 'TABLE', 'JOIN',)):
+        elif (item.ttype is Keyword or item.ttype is Keyword.DML) and item.value.upper() in (
+            "COPY",
+            "FROM",
+            "INTO",
+            "UPDATE",
+            "TABLE",
+            "JOIN",
+        ):
             tbl_prefix_seen = True
         # 'SELECT a, FROM abc' will detect FROM as part of the column list.
         # So this check here is necessary.
         elif isinstance(item, IdentifierList):
             for identifier in item.get_identifiers():
-                if (identifier.ttype is Keyword and
-                        identifier.value.upper() == 'FROM'):
+                if identifier.ttype is Keyword and identifier.value.upper() == "FROM":
                     tbl_prefix_seen = True
                     break
 
+
 def extract_table_identifiers(token_stream):
     """yields tuples of (schema_name, table_name, table_alias)"""
 
@@ -141,6 +145,7 @@ def extract_table_identifiers(token_stream):
         elif isinstance(item, Function):
             yield (None, item.get_name(), item.get_name())
 
+
 # extract_tables is inspired from examples in the sqlparse lib.
 def extract_tables(sql):
     """Extract the table names from an SQL statement.
@@ -156,27 +161,27 @@ def extract_tables(sql):
     # Punctuation. eg: INSERT INTO abc (col1, col2) VALUES (1, 2)
     # abc is the table name, but if we don't stop at the first lparen, then
     # we'll identify abc, col1 and col2 as table names.
-    insert_stmt = parsed[0].token_first().value.lower() == 'insert'
+    insert_stmt = parsed[0].token_first().value.lower() == "insert"
     stream = extract_from_part(parsed[0], stop_at_punctuation=insert_stmt)
     return list(extract_table_identifiers(stream))
 
+
 def find_prev_keyword(sql):
-    """ Find the last sql keyword in an SQL statement
+    """Find the last sql keyword in an SQL statement
 
     Returns the value of the last keyword, and the text of the query with
     everything after the last keyword stripped
     """
     if not sql.strip():
-        return None, ''
+        return None, ""
 
     parsed = sqlparse.parse(sql)[0]
     flattened = list(parsed.flatten())
 
-    logical_operators = ('AND', 'OR', 'NOT', 'BETWEEN')
+    logical_operators = ("AND", "OR", "NOT", "BETWEEN")
 
     for t in reversed(flattened):
-        if t.value == '(' or (t.is_keyword and (
-                              t.value.upper() not in logical_operators)):
+        if t.value == "(" or (t.is_keyword and (t.value.upper() not in logical_operators)):
             # Find the location of token t in the original parsed statement
             # We can't use parsed.token_index(t) because t may be a child token
             # inside a TokenList, in which case token_index thows an error
@@ -189,10 +194,10 @@ def find_prev_keyword(sql):
             # Combine the string values of all tokens in the original list
             # up to and including the target keyword token t, to produce a
             # query string with everything after the keyword token removed
-            text = ''.join(tok.value for tok in flattened[:idx+1])
+            text = "".join(tok.value for tok in flattened[: idx + 1])
             return t, text
 
-    return None, ''
+    return None, ""
 
 
 def query_starts_with(query, prefixes):
@@ -212,31 +217,25 @@ def queries_start_with(queries, prefixes):
 
 def query_has_where_clause(query):
     """Check if the query contains a where-clause."""
-    return any(
-        isinstance(token, sqlparse.sql.Where)
-        for token_list in sqlparse.parse(query)
-        for token in token_list
-    )
+    return any(isinstance(token, sqlparse.sql.Where) for token_list in sqlparse.parse(query) for token in token_list)
 
 
 def is_destructive(queries):
     """Returns if any of the queries in *queries* is destructive."""
-    keywords = ('drop', 'shutdown', 'delete', 'truncate', 'alter')
+    keywords = ("drop", "shutdown", "delete", "truncate", "alter")
     for query in sqlparse.split(queries):
         if query:
             if query_starts_with(query, keywords) is True:
                 return True
-            elif query_starts_with(
-                query, ['update']
-            ) is True and not query_has_where_clause(query):
+            elif query_starts_with(query, ["update"]) is True and not query_has_where_clause(query):
                 return True
 
     return False
 
 
-if __name__ == '__main__':
-    sql = 'select * from (select t. from tabl t'
-    print (extract_tables(sql))
+if __name__ == "__main__":
+    sql = "select * from (select t. from tabl t"
+    print(extract_tables(sql))
 
 
 def is_dropping_database(queries, dbname):
@@ -258,9 +257,7 @@ def is_dropping_database(queries, dbname):
             "database",
             "schema",
         ):
-            database_token = next(
-                (t for t in query.tokens if isinstance(t, Identifier)), None
-            )
+            database_token = next((t for t in query.tokens if isinstance(t, Identifier)), None)
             if database_token is not None and normalize_db_name(database_token.get_name()) == dbname:
                 result = keywords[0].normalized == "DROP"
     return result
