@@ -1,4 +1,5 @@
 """Test the mycli.clistyle module."""
+
 import pytest
 
 from pygments.style import Style
@@ -10,9 +11,9 @@ from mycli.clistyle import style_factory
 @pytest.mark.skip(reason="incompatible with new prompt toolkit")
 def test_style_factory():
     """Test that a Pygments Style class is created."""
-    header = 'bold underline #ansired'
-    cli_style = {'Token.Output.Header': header}
-    style = style_factory('default', cli_style)
+    header = "bold underline #ansired"
+    cli_style = {"Token.Output.Header": header}
+    style = style_factory("default", cli_style)
 
     assert isinstance(style(), Style)
     assert Token.Output.Header in style.styles
@@ -22,6 +23,6 @@ def test_style_factory():
 @pytest.mark.skip(reason="incompatible with new prompt toolkit")
 def test_style_factory_unknown_name():
     """Test that an unrecognized name will not throw an error."""
-    style = style_factory('foobar', {})
+    style = style_factory("foobar", {})
 
     assert isinstance(style(), Style)
